@@ -198,6 +198,7 @@ plotRes <- function(object,
     
     
     # ----- Part B: Data ----
+  
     
     plotData(TM = TM, 
              axis.ticks = axis.ticks, 
@@ -224,7 +225,7 @@ plotRes <- function(object,
     
     # ----- Get estimates out of model object -----
     
-    m_ind_allpw <- t(combn(1:5, 2)) # list all possible 2-way interactions
+    m_ind_allpw <- t(combn(1:p, 2)) # list all possible 2-way interactions
     n_pw <- nrow(m_ind_allpw) # how many?
     m_pw <- m_mod <- matrix(0, nrow=n_pw, ncol=nB) # Create storage for nB pairwise and moderation effects
     
@@ -293,6 +294,8 @@ plotRes <- function(object,
     tar_mat_pw <- tar_mat_pw[ord, ]
     tar_mat_mod <- tar_mat_mod[ord, ]
     
+    # browser()
+    
     # Subset (cut argument)
     if(is.null(cut)) {
       TM_pw <- tar_mat_pw
@@ -353,12 +356,14 @@ plotRes <- function(object,
              lwd.qtl = lwd.qtl, 
              cex.bg = cex.bg, 
              cex.mean = cex.mean, 
-             margins=margins)
+             margins = margins)
 
     # ----- C) Plot Moderation effects -----
     
     if(is.null(axis.ticks.mod)) axis.ticks.mod <- axis.ticks
     
+    # browser()
+    
     plotData(TM = TM_mod, 
              axis.ticks = axis.ticks.mod, 
              ylim = ylim, 
@@ -367,7 +372,7 @@ plotRes <- function(object,
              cex.bg = cex.bg, 
              cex.mean = cex.mean, 
              bgcol = "white", 
-             margins=margins)
+             margins = margins)
     
     
     
