@@ -97,6 +97,8 @@ predictCore_stat <- function(object,
         coefs <- as.numeric(nodeModels[[v]]$model) # get coefficients
         predCoreObj$pred[[v]] <- coefs[1] + X %*% matrix(coefs[-1], nrow=length(coefs[-1])) # predict
         
+        if(type[v]=="p") predCoreObj$pred[[v]] <- exp(predCoreObj$pred[[v]]) # coefficients of poisson regresison are on log scale
+        
       }
       
     } # end of variable loop 'mgm'
@@ -130,7 +132,6 @@ predictCore_stat <- function(object,
     
     for(v in 1:nNodes) {
       
-      
       # ----- Create VAR Design Matrix -----
       
       # append response with predictors
@@ -196,6 +197,8 @@ predictCore_stat <- function(object,
         coefs <- as.numeric(nodeModels[[v]]$model) # get coefficients
         predCoreObj$pred[[v]] <- coefs[1] + X %*% matrix(coefs[-1], nrow=length(coefs[-1])) # predict
         
+        if(type[v]=="p") predCoreObj$pred[[v]] <- exp(predCoreObj$pred[[v]])
+        
       }
       
     } # end loop: v
